@@ -228,6 +228,7 @@ typedef struct Prefix {
 /* survey metadata */
 typedef struct Meta_data {
     size_t ref_count;
+    /* Days since 1900 for start and end date of survey, or -1 if undated. */
     int days1, days2;
 } meta_data;
 
@@ -325,6 +326,13 @@ typedef struct Settings {
    int begin_lineno; /* 0 means no block started in this file */
    int flags;
    projPJ proj;
+   /* Location at which we calculate the declination if
+    * z[Q_DECLINATION] == HUGE_REAL. */
+   real dec_x, dec_y, dec_z;
+   /* Cached auto-declination, or HUGE_REAL for no cached value.  Only
+    * meaningful if date1 != -1.
+    */
+   real declination;
    meta_data * meta;
 } settings;
 
