@@ -118,9 +118,9 @@ CavernLogWindow::OnLinkClicked(const wxHtmlLinkInfo &link)
     // wxString cmd = wxT("x-terminal-emulator -title $t -e nano +$l $f");
     // wxString cmd = wxT("x-terminal-emulator -title $t -e jed -g $l $f");
 #endif
-    const char * p = getenv("SURVEXEDITOR");
+    wxChar * p = wxGetenv(wxT("SURVEXEDITOR"));
     if (p) {
-	cmd = wxString(p, wxConvUTF8);
+	cmd = p;
 	if (!cmd.find(wxT("$f"))) {
 	    cmd += wxT(" $f");
 	}
@@ -164,13 +164,8 @@ CavernLogWindow::OnLinkClicked(const wxHtmlLinkInfo &link)
 		++i;
 	}
     }
-#ifdef __WXMSW__
-    if (_wsystem(cmd.c_str()) >= 0)
+    if (wxSystem(cmd) >= 0)
 	return;
-#else
-    if (system(cmd.mb_str()) >= 0)
-	return;
-#endif
     wxString m;
     // TRANSLATORS: %s is replaced by the command we attempted to run.
     m.Printf(wmsg(/*Couldn’t run external command: “%s”*/17), cmd.c_str());
@@ -513,11 +508,7 @@ CavernLogWindow::OnSave(wxCommandEvent &)
 		     wxFD_SAVE|wxFD_OVERWRITE_PROMPT);
     if (dlg.ShowModal() != wxID_OK) return;
     filelog = dlg.GetPath();
-#ifdef __WXMSW__
-    FILE * fh_log = _wfopen(filelog.fn_str(), L"w");
-#else
-    FILE * fh_log = fopen(filelog.mb_str(), "w");
-#endif
+    FILE * fh_log = wxFopen(filelog, wxT("w"));
     if (!fh_log) {
 	wxGetApp().ReportError(wxString::Format(wmsg(/*Error writing to file “%s”*/110), filelog.c_str()));
 	return;
