@@ -40,6 +40,8 @@
 #include "readval.h"
 #include "str.h"
 
+static projPJ proj_wgs84;
+
 static void
 default_grade(settings *s)
 {
@@ -250,10 +252,10 @@ match_tok(const sztok *tab, int tab_size)
 
 typedef enum {
    CMD_NULL = -1, CMD_ALIAS, CMD_BEGIN, CMD_CALIBRATE, CMD_CASE, CMD_COPYRIGHT,
-   CMD_CS, CMD_DATA, CMD_DATE, CMD_DEFAULT, CMD_END, CMD_ENTRANCE, CMD_EQUATE,
-   CMD_EXPORT, CMD_FIX, CMD_FLAGS, CMD_INCLUDE, CMD_INFER, CMD_INSTRUMENT,
-   CMD_PREFIX, CMD_REQUIRE, CMD_SD, CMD_SET, CMD_SOLVE,
-   CMD_TEAM, CMD_TITLE, CMD_TRUNCATE, CMD_UNITS
+   CMD_CS, CMD_DATA, CMD_DATE, CMD_DECLINATION, CMD_DEFAULT, CMD_END,
+   CMD_ENTRANCE, CMD_EQUATE, CMD_EXPORT, CMD_FIX, CMD_FLAGS, CMD_INCLUDE,
+   CMD_INFER, CMD_INSTRUMENT, CMD_PREFIX, CMD_REQUIRE, CMD_SD, CMD_SET,
+   CMD_SOLVE, CMD_TEAM, CMD_TITLE, CMD_TRUNCATE, CMD_UNITS
 } cmds;
 
 static const sztok cmd_tab[] = {
@@ -265,6 +267,7 @@ static const sztok cmd_tab[] = {
      {"CS",        CMD_CS},
      {"DATA",      CMD_DATA},
      {"DATE",      CMD_DATE},
+     {"DECLINATION", CMD_DECLINATION},
 #ifndef NO_DEPRECATED
      {"DEFAULT",   CMD_DEFAULT},
 #endif
@@ -484,9 +487,9 @@ cmd_set(void)
 	 file.lpos += strlen(buffer);
 	 /* TRANSLATORS: Use of the ROOT character (which is "\" by default) is
 	  * deprecated, so this error would be generated by:
-	  * 
+	  *
 	  * *equate \foo.7 1
-	  * 
+	  *
 	  * If you're unsure what "deprecated" means, see:
 	  * http://en.wikipedia.org/wiki/Deprecation */
 	 compile_warning(-/*ROOT is deprecated*/25);
@@ -555,16 +558,16 @@ check_reentry(prefix *survey)
       /* TRANSLATORS: The first of two warnings given when a survey which has
        * already been completed is reentered.  This example file crawl.svx:
        *
-       * *begin crawl
-       * 1 2 9.45 234 -01 # <- second warning here
+       * *begin crawl     ; <- second warning here
+       * 1 2 9.45 234 -01
        * *end crawl
-       * *begin crawl     # <- first warning here
+       * *begin crawl     ; <- first warning here
        * 2 3 7.67 223 -03
        * *end crawl
        *
        * Would lead to:
        *
-       * crawl.svx:3: Reentering an existing survey is deprecated
+       * crawl.svx:4: Reentering an existing survey is deprecated
        * crawl.svx:1: Originally entered here
        *
        * If you're unsure what "deprecated" means, see:
@@ -650,7 +653,6 @@ bad:
 static void
 cmd_begin(void)
 {
-   prefix *survey;
    settings *pcsNew;
 
    pcsNew = osnew(settings);
@@ -659,9 +661,12 @@ cmd_begin(void)
    pcsNew->next = pcs;
    pcs = pcsNew;
 
-   survey = read_prefix(PFX_SURVEY|PFX_OPT|PFX_ALLOW_ROOT|PFX_WARN_SEPARATOR);
-   pcs->begin_survey = survey;
-   if (survey) {
+   skipblanks();
+   if (isEol(ch) || isComm(ch)) {
+      pcs->begin_survey = NULL;
+   } else {
+      prefix *survey = read_prefix(PFX_SURVEY|PFX_ALLOW_ROOT|PFX_WARN_SEPARATOR);
+      pcs->begin_survey = survey;
       pcs->Prefix = survey;
       check_reentry(survey);
       f_export_ok = fTrue;
@@ -715,7 +720,13 @@ cmd_end(void)
    pcs = pcsParent;
 
    /* note need to read using root *before* BEGIN */
-   survey = read_prefix(PFX_SURVEY|PFX_OPT|PFX_ALLOW_ROOT);
+   skipblanks();
+   if (isEol(ch) || isComm(ch)) {
+      survey = NULL;
+   } else {
+      survey = read_prefix(PFX_SURVEY|PFX_ALLOW_ROOT);
+   }
+
    if (survey != begin_survey) {
       if (survey) {
 	 if (!begin_survey) {
@@ -763,7 +774,6 @@ cmd_fix(void)
    static const char * name_omit_already_filename = NULL;
    static unsigned int name_omit_already_line;
    real x, y, z;
-   int nx, ny, nz;
    filepos fp;
 
    fix_name = read_prefix(PFX_STATION|PFX_ALLOW_ROOT);
@@ -778,11 +788,11 @@ cmd_fix(void)
       if (*ucbuffer) set_pos(&fp);
    }
 
-   x = read_numeric(fTrue, &nx);
+   x = read_numeric(fTrue);
    if (x == HUGE_REAL) {
       /* If the end of the line isn't blank, read a number after all to
        * get a more helpful error message */
-      if (!isEol(ch) && !isComm(ch)) x = read_numeric(fFalse, &nx);
+      if (!isEol(ch) && !isComm(ch)) x = read_numeric(fFalse);
    }
    if (x == HUGE_REAL) {
       if (pcs->proj || proj_out) {
@@ -815,9 +825,26 @@ cmd_fix(void)
       x = y = z = (real)0.0;
    } else {
       real sdx;
-      y = read_numeric(fFalse, &ny);
-      z = read_numeric(fFalse, &nz);
-      sdx = read_numeric(fTrue, NULL);
+      y = read_numeric(fFalse);
+      z = read_numeric(fFalse);
+
+      if (pcs->proj && proj_out) {
+	 if (pj_is_latlong(pcs->proj)) {
+	    /* PROJ expects lat and long in radians. */
+	    x = rad(x);
+	    y = rad(y);
+	 }
+	 int r = pj_transform(pcs->proj, proj_out, 1, 1, &x, &y, &z);
+	 if (r != 0) {
+	    compile_error(/*Failed to convert coordinates: %s*/436, pj_strerrno(r));
+	 }
+      } else if (pcs->proj) {
+	 compile_error(/*The input projection is set but the output projection isn't*/437);
+      } else if (proj_out) {
+	 compile_error(/*The output projection is set but the input projection isn't*/438);
+      }
+
+      sdx = read_numeric(fTrue);
       if (sdx <= 0) {
 	  compile_error_skip(-/*Standard deviation must be positive*/48);
 	  return;
@@ -825,7 +852,7 @@ cmd_fix(void)
       if (sdx != HUGE_REAL) {
 	 real sdy, sdz;
 	 real cxy = 0, cyz = 0, czx = 0;
-	 sdy = read_numeric(fTrue, NULL);
+	 sdy = read_numeric(fTrue);
 	 if (sdy == HUGE_REAL) {
 	    /* only one variance given */
 	    sdy = sdz = sdx;
@@ -834,7 +861,7 @@ cmd_fix(void)
 	       compile_error_skip(-/*Standard deviation must be positive*/48);
 	       return;
 	    }
-	    sdz = read_numeric(fTrue, NULL);
+	    sdz = read_numeric(fTrue);
 	    if (sdz == HUGE_REAL) {
 	       /* two variances given - horizontal & vertical */
 	       sdz = sdy;
@@ -844,11 +871,11 @@ cmd_fix(void)
 		  compile_error_skip(-/*Standard deviation must be positive*/48);
 		  return;
 	       }
-	       cxy = read_numeric(fTrue, NULL);
+	       cxy = read_numeric(fTrue);
 	       if (cxy != HUGE_REAL) {
 		  /* covariances given */
-		  cyz = read_numeric(fFalse, NULL);
-		  czx = read_numeric(fFalse, NULL);
+		  cyz = read_numeric(fFalse);
+		  czx = read_numeric(fFalse);
 	       } else {
 		  cxy = 0;
 	       }
@@ -885,20 +912,17 @@ cmd_fix(void)
 #endif
 		       );
 	 }
-	 return;
-      }
 
-      if (pcs->proj && proj_out) {
-	 int r = pj_transform(pcs->proj, proj_out, 1, 1, &x, &y, &z);
-	 if (r != 0) {
-	    compile_error(/*Failed to convert coordinates*/436);
-	    /* FIXME: report pj_strerrno(r) */
-	    printf("[%s]\n", pj_strerrno(r));
+	 if (!first_fix_name) {
+	    /* We track if we've fixed a station yet, and if so what the name
+	     * of the first fix was, so that we can issue an error if the
+	     * output coordinate system is set after fixing a station. */
+	    first_fix_name = fix_name;
+	    first_fix_filename = file.filename;
+	    first_fix_line = file.line;
 	 }
-      } else if (pcs->proj) {
-	 compile_error(/*The input projection is set but the output projection isn't*/437);
-      } else if (proj_out) {
-	 compile_error(/*The output projection is set but the input projection isn't*/438);
+
+	 return;
       }
    }
 
@@ -983,8 +1007,8 @@ cmd_equate(void)
    name1 = read_prefix(PFX_STATION|PFX_ALLOW_ROOT|PFX_SUSPECT_TYPO);
    while (fTrue) {
       name2 = name1;
-      name1 = read_prefix(PFX_STATION|PFX_ALLOW_ROOT|PFX_SUSPECT_TYPO|PFX_OPT);
-      if (name1 == NULL) {
+      skipblanks();
+      if (isEol(ch) || isComm(ch)) {
 	 if (fOnlyOneStn) {
 	    /* TRANSLATORS: EQUATE is a command name, so shouldn’t be
 	     * translated.
@@ -996,6 +1020,7 @@ cmd_equate(void)
 	 return;
       }
 
+      name1 = read_prefix(PFX_STATION|PFX_ALLOW_ROOT|PFX_SUSPECT_TYPO);
       process_equate(name1, name2);
       fOnlyOneStn = fFalse;
    }
@@ -1044,9 +1069,9 @@ cmd_export(void)
    prefix *pfx;
 
    fExportUsed = fTrue;
-   pfx = read_prefix(PFX_STATION);
    do {
       int depth = 0;
+      pfx = read_prefix(PFX_STATION);
       {
 	 prefix *p = pfx;
 	 while (p != NULL && p != pcs->Prefix) {
@@ -1074,7 +1099,7 @@ cmd_export(void)
 	    report_missing_export(pfx, depth);
 	 } else if (pfx->min_export - 1 < depth) {
 	    /* TRANSLATORS: Here "station" is a survey station, not a train station.
-	     * 
+	     *
 	     * Exporting a station twice gives this error:
 	     *
 	     * *begin example
@@ -1087,8 +1112,8 @@ cmd_export(void)
 	 }
 	 pfx->min_export = depth;
       }
-      pfx = read_prefix(PFX_STATION|PFX_OPT);
-   } while (pfx);
+      skipblanks();
+   } while (!isEol(ch) && !isComm(ch));
 }
 
 static void
@@ -1483,7 +1508,7 @@ cmd_units(void)
       return;
    }
 
-   factor = read_numeric(fTrue, NULL);
+   factor = read_numeric(fTrue);
    if (factor == 0.0) {
       /* TRANSLATORS: error message given by "*units tape 0 feet" - it’s
        * meaningless to say your tape is marked in "0 feet" (but you might
@@ -1534,11 +1559,32 @@ cmd_calibrate(void)
       return;
    }
 
-   z = read_numeric(fFalse, NULL);
-   sc = read_numeric(fTrue, NULL);
+   z = read_numeric(fFalse);
+   sc = read_numeric(fTrue);
+   if (sc == HUGE_REAL) {
+      if (isalpha(ch)) {
+	 int units = get_units(qmask, fFalse);
+	 if (units == UNITS_NULL) {
+	    return;
+	 }
+	 z *= factor_tab[units];
+	 sc = read_numeric(fTrue);
+	 if (sc == HUGE_REAL) {
+	    sc = (real)1.0;
+	 } else {
+	    /* Adjustment applied is: (reading - z) * sc
+	     * We want: reading * sc - z
+	     * So divide z by sc so the applied adjustment does what we want.
+	     */
+	    z /= sc;
+	 }
+      } else {
+	 sc = (real)1.0;
+      }
+   }
+
    if (sc == HUGE_REAL) sc = (real)1.0;
    /* check for declination scale */
-   /* perhaps "*calibrate declination XXX" should be "*declination XXX" ? */
    if (TSTBIT(qmask, Q_DECLINATION) && sc != 1.0) {
       /* TRANSLATORS: DECLINATION is a built-in keyword, so best not to
        * translate */
@@ -1559,6 +1605,52 @@ cmd_calibrate(void)
    }
 }
 
+static void
+cmd_declination(void)
+{
+    real v = read_numeric(fTrue);
+    if (v == HUGE_REAL) {
+	get_token_no_blanks();
+	if (strcmp(ucbuffer, "AUTO") != 0) {
+	    compile_error_skip(-/*Expected number or 'AUTO'*/309);
+	    return;
+	}
+	/* *declination auto X Y Z */
+	real x = read_numeric(fFalse);
+	real y = read_numeric(fFalse);
+	real z = read_numeric(fFalse);
+	if (!pcs->proj) {
+	    compile_error(/*Input coordinate system must be specified for '*DECLINATION AUTO'*/301);
+	    return;
+	}
+	if (!proj_wgs84) {
+	    proj_wgs84 = pj_init_plus("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs");
+	}
+	/* Convert to WGS84 lat long. */
+	if (pj_is_latlong(pcs->proj)) {
+	    /* PROJ expects lat and long in radians. */
+	    x = rad(x);
+	    y = rad(y);
+	}
+	int r = pj_transform(pcs->proj, proj_wgs84, 1, 1, &x, &y, &z);
+	if (r != 0) {
+	    compile_error(/*Failed to convert coordinates: %s*/436, pj_strerrno(r));
+	    return;
+	}
+	pcs->z[Q_DECLINATION] = HUGE_REAL;
+	pcs->dec_x = x;
+	pcs->dec_y = y;
+	pcs->dec_z = z;
+    } else {
+	/* *declination D UNITS */
+	int units = get_units(BIT(Q_DECLINATION), fFalse);
+	if (units == UNITS_NULL) {
+	    return;
+	}
+	pcs->z[Q_DECLINATION] = -v * factor_tab[units];
+    }
+}
+
 #ifndef NO_DEPRECATED
 static void
 cmd_default(void)
@@ -1646,7 +1738,7 @@ cmd_sd(void)
       default_grade(pcs);
       return;
    }
-   sd = read_numeric(fFalse, NULL);
+   sd = read_numeric(fFalse);
    if (sd <= (real)0.0) {
       compile_error_skip(-/*Standard deviation must be positive*/48);
       return;
@@ -1789,7 +1881,7 @@ cmd_cs(void)
 	 }
 	 break;
       case CS_JTSK:
-         ok_for_output = NO;
+	 ok_for_output = NO;
 	 /* FALLTHRU */
       case CS_IJTSK:
 	 if (ch == '0') {
@@ -2159,12 +2251,19 @@ cmd_date(void)
 
     if (days2 < days1) {
 	compile_error(-/*End of date range is before the start*/81);
+	int tmp = days1;
+	days1 = days2;
+	days2 = tmp;
     }
 
 read:
-    copy_on_write_meta(pcs);
-    pcs->meta->days1 = days1;
-    pcs->meta->days2 = days2;
+    if (!pcs->meta || pcs->meta->days1 != days1 || pcs->meta->days2 != days2) {
+	copy_on_write_meta(pcs);
+	pcs->meta->days1 = days1;
+	pcs->meta->days2 = days2;
+	/* Invalidate cached declination. */
+	pcs->declination = HUGE_REAL;
+    }
 }
 
 typedef void (*cmd_fn)(void);
@@ -2178,6 +2277,7 @@ static const cmd_fn cmd_funcs[] = {
    cmd_cs,
    cmd_data,
    cmd_date,
+   cmd_declination,
 #ifndef NO_DEPRECATED
    cmd_default,
 #endif
