@@ -38,6 +38,7 @@
 #include "commands.h"
 #include "out.h"
 #include "str.h"
+#include "thgeomag.h"
 
 #define EPSILON (REAL_EPSILON * 1000)
 
@@ -341,7 +342,7 @@ read_reading(reading r, bool f_optional)
 	q = Q_NULL; /* Suppress compiler warning */;
 	BUG("Unexpected case");
    }
-   VAL(r) = read_numeric(f_optional, &n_readings);
+   VAL(r) = read_numeric_multi(f_optional, &n_readings);
    VAR(r) = var(q);
    if (n_readings > 1) VAR(r) /= sqrt(n_readings);
 }
@@ -351,7 +352,7 @@ read_bearing_or_omit(reading r)
 {
    int n_readings;
    q_quantity q = Q_NULL;
-   VAL(r) = read_numeric_or_omit(&n_readings);
+   VAL(r) = read_numeric_multi_or_omit(&n_readings);
    switch (r) {
       case Comp: q = Q_BEARING; break;
       case BackComp: q = Q_BACKBEARING; break;
@@ -558,6 +559,7 @@ data_file(const char *pth, const char *fnm)
 	 } else {
 	     pcs->meta->days1 = pcs->meta->days2 = -1;
 	 }
+	 pcs->declination = HUGE_REAL;
 	 skipline();
 	 process_eol();
 	 /* SURVEY TEAM: */
@@ -573,7 +575,7 @@ data_file(const char *pth, const char *fnm)
 	 get_token();
 	 nextch(); /* : */
 	 skipblanks();
-	 pcs->z[Q_DECLINATION] = -read_numeric(fFalse, NULL);
+	 pcs->z[Q_DECLINATION] = -read_numeric(fFalse);
 	 pcs->z[Q_DECLINATION] *= pcs->units[Q_DECLINATION];
 	 get_token();
 	 pcs->ordering = compass_order;
@@ -588,9 +590,9 @@ data_file(const char *pth, const char *fnm)
 	 }
 	 if (strcmp(buffer, "CORRECTIONS") == 0) {
 	    nextch(); /* : */
-	    pcs->z[Q_BEARING] = -rad(read_numeric(fFalse, NULL));
-	    pcs->z[Q_GRADIENT] = -rad(read_numeric(fFalse, NULL));
-	    pcs->z[Q_LENGTH] = -read_numeric(fFalse, NULL);
+	    pcs->z[Q_BEARING] = -rad(read_numeric(fFalse));
+	    pcs->z[Q_GRADIENT] = -rad(read_numeric(fFalse));
+	    pcs->z[Q_LENGTH] = -read_numeric(fFalse);
 	 } else {
 	    pcs->z[Q_BEARING] = 0;
 	    pcs->z[Q_GRADIENT] = 0;
@@ -659,17 +661,17 @@ data_file(const char *pth, const char *fnm)
 			    ch != '.' && ch != ']' && ch != EOF) {
 			nextch_handling_eol();
 		     }
-		     x = read_numeric(fFalse, NULL);
+		     x = read_numeric(fFalse);
 		     while (!isdigit(ch) && ch != '+' && ch != '-' &&
 			    ch != '.' && ch != ']' && ch != EOF) {
 			nextch_handling_eol();
 		     }
-		     y = read_numeric(fFalse, NULL);
+		     y = read_numeric(fFalse);
 		     while (!isdigit(ch) && ch != '+' && ch != '-' &&
 			    ch != '.' && ch != ']' && ch != EOF) {
 			nextch_handling_eol();
 		     }
-		     z = read_numeric(fFalse, NULL);
+		     z = read_numeric(fFalse);
 		     stn = StnFromPfx(name);
 		     if (!fixed(stn)) {
 			POS(stn, 0) = x;
@@ -890,14 +892,35 @@ handle_compass(real *p_var)
    real compvar = VAR(Comp);
    real comp = VAL(Comp);
    real backcomp = VAL(BackComp);
+   real declination;
+   if (pcs->z[Q_DECLINATION] != HUGE_REAL) {
+      declination = -pcs->z[Q_DECLINATION];
+   } else if (pcs->declination != HUGE_REAL) {
+      declination = pcs->declination;
+   } else {
+      if (!pcs->meta || pcs->meta->days1 == -1) {
+	  compile_warning(/*No survey date specified - using 0 for magnetic declination*/304);
+	  declination = 0;
+      } else {
+	  int avg_days = (pcs->meta->days1 + pcs->meta->days2) / 2;
+	  double dat = julian_date_from_days_since_1900(avg_days);
+	  /* thgeomag() takes (lat, lon, h, dat) - i.e. (y, x, z, date). */
+	  declination = thgeomag(pcs->dec_y, pcs->dec_x, pcs->dec_z, dat);
+      }
+      /* We cache the calculated declination as the calculation is relatively
+       * expensive.  We also calculate an "assumed 0" answer so that we only
+       * warn once per such survey rather than for every line with a compass
+       * reading. */
+      pcs->declination = declination;
+   }
    if (comp != HUGE_REAL) {
       comp = (comp - pcs->z[Q_BEARING]) * pcs->sc[Q_BEARING];
-      comp -= pcs->z[Q_DECLINATION];
+      comp += declination;
    }
    if (backcomp != HUGE_REAL) {
       backcomp = (backcomp - pcs->z[Q_BACKBEARING])
 	      * pcs->sc[Q_BACKBEARING];
-      backcomp -= pcs->z[Q_DECLINATION];
+      backcomp += declination;
       backcomp -= M_PI;
       if (comp != HUGE_REAL) {
 	 real diff = comp - backcomp;
@@ -1286,6 +1309,10 @@ process_diving(prefix *fr, prefix *to, bool fToFirst, bool fDepthChange)
 	 czx = -2 * VAR(ToDepth) * dx / D;
 #endif
       }
+      /* FIXME: If there's a clino reading, check it against the depth reading,
+       * and average.
+       * if (VAL(Clino) != HUGE_REAL || VAL(BackClino) != HUGE_REAL) { ... }
+       */
    }
    addlegbyname(fr, to, fToFirst, dx, dy, dz, vx, vy, vz
 #ifndef NO_COVARIANCES
@@ -1836,14 +1863,14 @@ data_passage(void)
 	 break;
        case Left: case Right: case Up: case Down:
 	 read_reading(*ordering, fTrue);
-         if (VAL(*ordering) == HUGE_REAL) {
-            if (!isOmit(ch)) {
+	 if (VAL(*ordering) == HUGE_REAL) {
+	    if (!isOmit(ch)) {
 	       compile_error_token(-/*Expecting numeric field, found “%s”*/9);
 	    } else {
 	       nextch();
-            }
-            VAL(*ordering) = -1;
-         }
+	    }
+	    VAL(*ordering) = -1;
+	 }
 	 break;
        case Ignore:
 	 skipword(); break;
