@@ -206,15 +206,15 @@ public:
     }
     PresentationMark GetMark() const {
 	double a, t, s, T;
-	Vector3 v(atof(easting->GetValue().mb_str()),
-		  atof(northing->GetValue().mb_str()),
-		  atof(altitude->GetValue().mb_str()));
-	a = atof(angle->GetValue().mb_str());
-	t = atof(tilt_angle->GetValue().mb_str());
-	s = atof(scale->GetValue().mb_str());
+	Vector3 v(wxAtof(easting->GetValue()),
+		  wxAtof(northing->GetValue()),
+		  wxAtof(altitude->GetValue()));
+	a = wxAtof(angle->GetValue());
+	t = wxAtof(tilt_angle->GetValue());
+	s = wxAtof(scale->GetValue());
 	wxString str = time->GetValue();
 	if (!str.empty() && str[0u] == '*') str[0u] = '-';
-	T = atof(str.mb_str());
+	T = wxAtof(str);
 	return PresentationMark(v, a, t, s, T);
     }
 
@@ -379,11 +379,7 @@ class AvenPresList : public wxListCtrl {
 		fnm = dlg.GetPath();
 	    }
 
-#ifdef __WXMSW__
-	    FILE * fh_pres = _wfopen(fnm.fn_str(), L"w");
-#else
-	    FILE * fh_pres = fopen(fnm.mb_str(), "w");
-#endif
+	    FILE * fh_pres = wxFopen(fnm, wxT("w"));
 	    if (!fh_pres) {
 		wxGetApp().ReportError(wxString::Format(wmsg(/*Error writing to file “%s”*/110), fnm.c_str()));
 		return;
@@ -420,11 +416,7 @@ class AvenPresList : public wxListCtrl {
 	    force_save_as = true;
 	}
 	bool Load(const wxString &fnm) {
-#ifdef __WXMSW__
-	    FILE * fh_pres = _wfopen(fnm.fn_str(), L"r");
-#else
-	    FILE * fh_pres = fopen(fnm.mb_str(), "r");
-#endif
+	    FILE * fh_pres = wxFopen(fnm, wxT("r"));
 	    if (!fh_pres) {
 		wxString m;
 		m.Printf(wmsg(/*Couldn’t open file “%s”*/24), fnm.c_str());
@@ -1244,9 +1236,9 @@ bool MainFrm::LoadData(const wxString& file, const wxString & prefix)
 			++n_traverses;
 			// The previous point was at a surface->ug transition.
 			if (current_polyline_is_surface) {
-    			    if (prev_pt.z < m_DepthMin) m_DepthMin = prev_pt.z;
-    			    if (prev_pt.z > depthmax) depthmax = prev_pt.z;
-                        }
+			    if (prev_pt.z < m_DepthMin) m_DepthMin = prev_pt.z;
+			    if (prev_pt.z > depthmax) depthmax = prev_pt.z;
+			}
 		    }
 
 		    current_polyline_is_surface = is_surface;
@@ -1976,7 +1968,7 @@ void MainFrm::OnOpen(wxCommandEvent&)
     /* TRANSLATORS: Here "survey" is a "cave map" rather than list of questions
      * - it should be translated to the terminology that cavers using the
      * language would use.
-     * 
+     *
      * File->Open dialog: */
     wxFileDialog dlg(this, wmsg(/*Select a survey file to view*/206),
 		     wxString(), wxString(),
@@ -2234,7 +2226,7 @@ void MainFrm::SetCoords(Double x, Double y, const LabelInfo * there)
 	    brg *= 400.0 / 360.0;
 	    /* TRANSLATORS: alternative angle units (400 grad = 360 degrees =
 	     * full circle).  Try to make this as short as sensibly possible.
-	     * 
+	     *
 	     * E.g. in Italian and Spanish we use "g.cent." rather than
 	     * "gradi quattrocentesimali"/"grados centesimales" */
 	    brg_unit = /*grad*/345;
@@ -2449,9 +2441,9 @@ void MainFrm::OnPresOpen(wxCommandEvent&)
 #else
     wxFileDialog dlg(this, wmsg(/*Select a presentation to open*/322), wxString(), wxString(),
 		     wxString::Format(wxT("%s|*.fly|%s|%s"),
-		       	       wmsg(/*Aven presentations*/320).c_str(),
-		       	       wmsg(/*All files*/208).c_str(),
-		       	       wxFileSelectorDefaultWildcardStr),
+			       wmsg(/*Aven presentations*/320).c_str(),
+			       wmsg(/*All files*/208).c_str(),
+			       wxFileSelectorDefaultWildcardStr),
 		     wxFD_OPEN|wxFD_FILE_MUST_EXIST);
 #endif
     if (dlg.ShowModal() == wxID_OK) {
