@@ -810,6 +810,9 @@ parse_msg_file(int charset_code)
    /* trim off charset from stuff like "de_DE.iso8859_1" */
    s = strchr(fnm, '.');
    if (s) *s = '\0';
+   /* trim off any "@<something>" modifier. */
+   s = strchr(fnm, '@');
+   if (s) *s = '\0';
 
    fh = fopenWithPthAndExt(pth_cfg_files, fnm, EXT_SVX_MSG, "rb", NULL);
 
@@ -821,7 +824,7 @@ parse_msg_file(int charset_code)
    }
 
    if (!fh && !msg_lang_explicit) {
-      /* If msg_lang wasn't specified using environment variable SURVEX_LANG,
+      /* If msg_lang wasn't specified using environment variable SURVEXLANG,
        * then default to 'en' if we don't find messages for language msg_lang.
        */
       if (fnm[0] && fnm[1]) {
@@ -1118,23 +1121,21 @@ macosx_got_msg:
    /* On Mandrake LANG defaults to C */
    if (strcmp(msg_lang, "C") == 0) msg_lang = "en";
 
-   msg_lang = osstrdup(msg_lang);
-
-   /* Convert en-us to en_US, etc */
-   p = strchr(msg_lang, '-');
-   if (p) {
-      *p++ = '_';
-      while (*p) {
-	 *p = toupper(*p);
-	 p++;
+   { /* If msg_lang has a country code, snip it out to give msg_lang2. */
+      size_t b = 0;
+      while (isalpha((unsigned char)msg_lang[b])) {
+	 ++b;
+      }
+      if (msg_lang[b] == '_') {
+	 char * tmp;
+	 size_t e = b + 1;
+	 while (isalpha((unsigned char)msg_lang[e])) {
+	    ++e;
+	 }
+	 tmp = osstrdup(msg_lang);
+	 memmove(tmp + b, tmp + e, strlen(tmp + e) + 1);
+	 msg_lang2 = tmp;
       }
-   }
-
-   p = strchr(msg_lang, '_');
-   if (p) {
-      *p = '\0';
-      msg_lang2 = osstrdup(msg_lang);
-      *p = '_';
    }
 
 #ifdef LC_MESSAGES
